aboutsummaryrefslogtreecommitdiff
path: root/common/system.h
diff options
context:
space:
mode:
Diffstat (limited to 'common/system.h')
-rw-r--r--common/system.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/common/system.h b/common/system.h
index 85a9f6a77e..dc74533861 100644
--- a/common/system.h
+++ b/common/system.h
@@ -52,7 +52,7 @@ class TimerManager;
class SeekableReadStream;
class WriteStream;
#ifdef ENABLE_KEYMAPPER
-class HardwareKeySet;
+class HardwareInputSet;
class Keymap;
class KeymapperDefaultBindings;
#endif
@@ -938,15 +938,15 @@ public:
#ifdef ENABLE_KEYMAPPER
/**
- * Register hardware keys with keymapper
+ * Register hardware inputs with keymapper
* IMPORTANT NOTE: This is part of the WIP Keymapper. If you plan to use
* this, please talk to tsoliman and/or LordHoto.
*
* @return HardwareKeySet with all keys and recommended mappings
*
* See keymapper documentation for further reference.
*/
- virtual Common::HardwareKeySet *getHardwareKeySet() { return 0; }
+ virtual Common::HardwareInputSet *getHardwareInputSet() { return 0; }
/**
* Return a platform-specific global keymap
@@ -938,15 +938,15 @@ public:
* this, please talk to tsoliman and/or LordHoto.
*
- * @return HardwareKeySet with all keys and recommended mappings
+ * @return HardwareInputSet with all keys and recommended mappings
*
* See keymapper documentation for further reference.